﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.Drawing;
using Syncfusion.OfficeChart;
using System;
using System.Collections.Generic;
using System.Data;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;
using Syncfusion.DocIORenderer;
using Syncfusion.Pdf;
using System.Collections;

namespace XamarinFormsApp1
{
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();
        }
        DataSet ds = new DataSet();
        // List<WParagraph> list = new List<WParagraph>();
        List<WordImageParagraph> list = new List<WordImageParagraph>();
        private void Button_Clicked(object sender, EventArgs e)
        {

            Assembly assembly = typeof(App).GetTypeInfo().Assembly;
            WordDocument document = new WordDocument(assembly.GetManifestResourceStream("XamarinFormsApp1.Assets.Template.doc"), FormatType.Doc);
            
            // Get the tables from Data Set.
            GetDataTable();

            // Using Merge events to do conditional formatting during runtime.
            document.MailMerge.MergeImageField += new MergeImageFieldEventHandler(MergeField_ProductImage);

            // Execute Mail Merge with groups.
            document.MailMerge.ExecuteGroup(ds.Tables["Products"]);
            document.MailMerge.ExecuteGroup(ds.Tables["Product_PriceList"]);

            foreach (var item in list)
            {
                WParagraph paragraph = item.paragraph as WParagraph;

                //Fields are updated with pictures.
                //Gets picture from the index of image field.
                WPicture picture = paragraph.Items[item.Index] as WPicture;
                if (picture != null)
                {
                    //Changes the size of picture.
                    picture.Height = 40;
                    picture.Width = 65;
                }
            }
            //Saves the Word file to MemoryStream
            MemoryStream stream = new MemoryStream();
            document.Save(stream, FormatType.Docx);
            //Closes the Word document
            document.Close();
            //Save the stream as a file in the device and invoke it for viewing
            Xamarin.Forms.DependencyService.Get<ISave>().SaveAndView("Template.docx", "application/msword", stream);
        }
        private void MergeField_ProductImage(object sender, MergeImageFieldEventArgs args)
        {
            Assembly assembly = typeof(App).GetTypeInfo().Assembly;
            // Get the image from disk during Merge.
            if (args.FieldName == "ProductImage")
            {
                string ProductFileName = args.FieldValue.ToString();
                args.ImageStream = assembly.GetManifestResourceStream("XamarinFormsApp1.Assets." + ProductFileName);
                WParagraph paragraph = args.CurrentMergeField.OwnerParagraph;
                //pictureFieldsData.Add(paragraph, paragraph.Items.IndexOf(args.CurrentMergeField));
                list.Add(new WordImageParagraph { paragraph = paragraph, Index = paragraph.Items.IndexOf(args.CurrentMergeField) });
            }
        }
        private void GetDataTable()
        {
            // List of syncfusion products name.        
            string[] products = { "Apple Juice", "Grape Juice", "Hot Soup", "Tender Coconut", "Vennila", "Strawberry", "Cherry", "Cone" };

            // Add new Tables to the data set.
            DataRow row;
            ds.Tables.Add();
            ds.Tables.Add();

            // Add fields to the Product_PriceList table.
            ds.Tables[0].TableName = "Product_PriceList";
            ds.Tables[0].Columns.Add("ProductName");
            ds.Tables[0].Columns.Add("Price");

            // Add fields to the Products table.
            ds.Tables[1].TableName = "Products";
            ds.Tables[1].Columns.Add("SNO");
            ds.Tables[1].Columns.Add("ProductName");
            ds.Tables[1].Columns.Add("ProductImage");

            int count = 0;

            // Inserting values to the tables.
            foreach (string product in products)
            {
                row = ds.Tables["Product_PriceList"].NewRow();
                row["ProductName"] = product;
                switch (product)
                {
                    case "Apple Juice":
                        row["Price"] = "$12.00"; break;
                    case "Grape Juice":
                        row["Price"] = "$15.00"; break;
                    case "Hot Soup":
                        row["Price"] = "$20.00"; break;
                    case "Tender coconut":
                        row["Price"] = "$10.00"; break;
                    case "Vennila Ice Cream":
                        row["Price"] = "$15.00"; break;
                    case "Strawberry":
                        row["Price"] = "$18.00"; break;
                    case "Cherry":
                        row["Price"] = "$25.00"; break;
                    default:
                        row["Price"] = "$20.00"; break;
                }

                ds.Tables["Product_PriceList"].Rows.Add(row);

                count++;
                row = ds.Tables["Products"].NewRow();
                row["SNO"] = count.ToString();
                row["ProductName"] = product;
                row["ProductImage"] = string.Concat(product, ".png");
                ds.Tables["Products"].Rows.Add(row);
            }
        }  
    }
}
